@@ -24,15 +24,17 @@
 
 #include <gtk/gtk.h>
 
+#include "app.h"
+
+
 /*    funzioni per la navigazione  tra le schede inserite
 */
-void rubrica_browse_save_path(GtkTreePath *path);
 
-void rubrica_browse_first_card(GtkTreeSelection *select, GtkTreeModel *model);
-void rubrica_browse_last_card(GtkTreeSelection *select, GtkTreeModel *model);
-void rubrica_browse_next_card(GtkTreeSelection *select, GtkTreeModel *model);
-void rubrica_browse_prev_card(GtkTreeSelection *select, GtkTreeModel *model);
-void rubrica_browse_nth_card(gchar *path_str);
+void rubrica_browse_first_card    (RubricaApp* app);
+void rubrica_browse_last_card     (RubricaApp* app);
+void rubrica_browse_next_card     (RubricaApp* app);
+void rubrica_browse_previous_card (RubricaApp* app);
+void rubrica_browse_nth_card      (RubricaApp* app, gchar *path_str);
 
 
 #endif
